Class: SacsRuby::API::LowFareForecast

Inherits:
Base
  • Object
show all
Defined in:
lib/sacs_ruby/api/low_fare_forecast.rb

Overview

The Low Fare Forecast API forecasts the price range into which the lowest published fare that is available via the Sabre GDS is predicted to fall within the next 7 days, for a specific origin and destination on specific roundtrip travel dates.

Instance Attribute Summary

Attributes inherited from Base

#opts, #results, #token, #url

Instance Method Summary collapse

Methods inherited from Base

get, #get, #initialize, #valid?

Constructor Details

This class inherits a constructor from SacsRuby::Base

Instance Method Details

#endpoint_urlObject



14
15
16
# File 'lib/sacs_ruby/api/low_fare_forecast.rb', line 14

def endpoint_url
  '/v1/forecast/flights/fares'
end

#required_varsObject



10
11
12
# File 'lib/sacs_ruby/api/low_fare_forecast.rb', line 10

def required_vars
  i(origin destination departuredate returndate)
end