Class: SacsRuby::API::FareRange
- Defined in:
- lib/sacs_ruby/api/fare_range.rb
Overview
The Fare Range API returns the median, highest, and lowest published fares that were ticketed via the Sabre GDS during the previous 4 weeks for each of the future departure dates in a range, using the specific origin, destination, and length of stay in the request. In the request, future departure dates can range from 0-90 days, from the day of the API request. Length of stay is any single value from 0-16 days. The API also returns a rating of high, medium, or low, which represents the quantity of tickets that the API referenced to obtain the published fare values.
Instance Attribute Summary
Attributes inherited from Base
Instance Method Summary collapse
Methods inherited from Base
get, #get, #initialize, #valid?
Constructor Details
This class inherits a constructor from SacsRuby::Base
Instance Method Details
#endpoint_url ⇒ Object
20 21 22 |
# File 'lib/sacs_ruby/api/fare_range.rb', line 20 def endpoint_url '/v1/historical/flights/fares' end |
#required_vars ⇒ Object
15 16 17 18 |
# File 'lib/sacs_ruby/api/fare_range.rb', line 15 def required_vars i(origin destination earliestdeparturedate latestdeparturedate lengthofstay) end |