Class: SacsRuby::API::PointOfSaleCountryCodeLookup
- Defined in:
- lib/sacs_ruby/api/point_of_sale_country_code_lookup.rb
Overview
Point of Sale Country Code Lookup is a supplemental API that retrieves a list of supported point of sale country codes and associated country names. The country codes can be passed as a parameter in certain REST API requests (those which support a ‘pointofsalecountry’ parameter). When a point of sale country is submitted with the request, only data related to that point of sale will be included in the response.
Instance Attribute Summary
Attributes inherited from Base
Instance Method Summary collapse
Methods inherited from Base
get, #get, #initialize, #valid?
Constructor Details
This class inherits a constructor from SacsRuby::Base
Instance Method Details
#endpoint_url ⇒ Object
12 13 14 |
# File 'lib/sacs_ruby/api/point_of_sale_country_code_lookup.rb', line 12 def endpoint_url '/v1/lists/supported/pointofsalecountries' end |